@@ -1,10 +1,11 @@
 import sys
+from abc import ABCMeta, abstractmethod
 from typing import Optional
 
 from PyQt5.QtCore import QObject, QRect, QPoint, QDir, pyqtSignal, Qt
 from PyQt5.QtGui import QGuiApplication, QPixmap, QKeyEvent, QPaintEvent, QPainter, QColor, QMouseEvent, \
     QRegion
-from PyQt5.QtWidgets import QApplication, QWidget
+from PyQt5.QtWidgets import QApplication, QWidget, QFrame, QHBoxLayout, QPushButton
 
 from fastocr.util import DesktopInfo
 
@@ -108,6 +109,74 @@ class ScreenGrabber(QObject):
         return pixmap
 
 
+class BaseToolButton(QPushButton):
+    def __init__(self, parent=None, widget=None):
+        super(BaseToolButton, self).__init__(parent=parent)
+        self._capture_widget: CaptureWidget = widget
+        self.setText(self.get_text())
+        self.setStyleSheet(
+            "QPushButton { background-color: #06b9d4; color: #ffffff; font-weight: 500; border: 0; padding: 5px 15px; "
+            "font-size: 12px;}"
+            "QPushButton:hover { background-color: #05a8be; color: #ffffff; }"
+            "QPushButton:pressed { background-color: #05a8be; color: #ffffff; }")
+        # noinspection PyUnresolvedReferences
+        self.clicked.connect(self.click_triggered)
+
+    def click_triggered(self, _):
+        self.handle(self._capture_widget)
+
+    @abstractmethod
+    def get_text(self) -> str:
+        pass
+
+    @abstractmethod
+    def handle(self, widget: 'CaptureWidget'):
+        pass
+
+
+class CloseButton(BaseToolButton):
+    def get_text(self) -> str:
+        return 'Close'
+
+    def handle(self, widget: 'CaptureWidget'):
+        widget._tool_panel.hide()
+        widget.close()
+
+
+class FastCopyButton(BaseToolButton):
+    def get_text(self) -> str:
+        return 'Copy'
+
+    def handle(self, widget: 'CaptureWidget'):
+        widget.fast_copy()
+
+
+class ToolPanel(QFrame):
+    def __init__(self, parent=None):
+        super(ToolPanel, self).__init__(parent)
+        self._layout: Optional[QHBoxLayout] = None
+        self.setup_ui()
+        self.setup_tools()
+
+    def setup_ui(self):
+        self.setContentsMargins(0, 0, 0, 0)
+        self.setWindowFlags(
+            Qt.WindowStaysOnTopHint | Qt.FramelessWindowHint | Qt.Tool |
+            Qt.BypassWindowManagerHint)
+        self.setFocusPolicy(Qt.NoFocus)
+        self.setStyleSheet("background-color: transparent;")
+        self.setAttribute(Qt.WA_TranslucentBackground)
+        self.setWindowOpacity(.8)
+        self._layout = QHBoxLayout(self)
+        self._layout.setContentsMargins(0, 0, 0, 0)
+        self.setLayout(self._layout)
+
+    def setup_tools(self):
+        self._layout.addWidget(CloseButton(self, self.parentWidget()))
+        self._layout.addWidget(FastCopyButton(self, self.parentWidget()))
+        # self._layout.addWidget(QPushButton('Search Text', self))
+
+
 class CaptureWidget(QWidget):
     captured = pyqtSignal(QPixmap)
 
@@ -127,6 +196,7 @@ class CaptureWidget(QWidget):
         self._clipping_state = 0
         self._startpos: Optional[QPoint] = None
         self._endpos: Optional[QPoint] = None
+        self._tool_panel = ToolPanel(self)
         self.move(0, 0)
         self.resize(self.screenshot.size())
 
@@ -138,20 +208,25 @@ class CaptureWidget(QWidget):
         :type event: QKeyEvent
         """
         if event.key() == Qt.Key.Key_Escape:
+            self._tool_panel.hide()
             self.close()
         if event.key() in [Qt.Key.Key_Return, Qt.Key.Key_Enter]:
-            if self._startpos is None or self._endpos is None:
-                return
-            screen = QApplication.screenAt(self._startpos)
-            ratio = screen.devicePixelRatio()
-            cropped = self.screenshot.copy(QRect(
-                int(self._startpos.x() * ratio),
-                int(self._startpos.y() * ratio),
-                int((self._endpos.x() - self._startpos.x()) * ratio),
-                int((self._endpos.y() - self._startpos.y()) * ratio),
-            ))
-            # noinspection PyUnresolvedReferences
-            self.captured.emit(cropped)
+            self.fast_copy()
+
+    def fast_copy(self):
+        self._tool_panel.hide()
+        if self._startpos is None or self._endpos is None:
+            return
+        screen = QApplication.screenAt(self._startpos)
+        ratio = screen.devicePixelRatio()
+        cropped = self.screenshot.copy(QRect(
+            int(self._startpos.x() * ratio),
+            int(self._startpos.y() * ratio),
+            int((self._endpos.x() - self._startpos.x()) * ratio),
+            int((self._endpos.y() - self._startpos.y()) * ratio),
+        ))
+        # noinspection PyUnresolvedReferences
+        self.captured.emit(cropped)
 
     def mousePressEvent(self, event: QMouseEvent):
         """
@@ -161,6 +236,7 @@ class CaptureWidget(QWidget):
         """
         self._clipping_state = 1
         self._startpos = event.pos()
+        self._tool_panel.hide()
 
     def mouseMoveEvent(self, event: QMouseEvent):
         """
@@ -182,6 +258,14 @@ class CaptureWidget(QWidget):
         self._clipping_state = 2
         self._endpos = event.pos()
         self.repaint()
+        self.show_panel_at_mouse()
+
+    def show_panel_at_mouse(self):
+        self._tool_panel.show()
+        pos_x = self._endpos.x() - self._tool_panel.width()
+        pos_y = self._endpos.y() + 4
+        # TODO: potentially move out of screen
+        self._tool_panel.move(pos_x, pos_y)
 
     def paintEvent(self, event: QPaintEvent):
         """
