@@ -15,7 +15,7 @@ from fastocr.consts import APP_SETTING_FILE
 from fastocr.grabber import CaptureWidget
 from fastocr.service import OcrService, BaiduOcr
 from fastocr.setting import Setting
-from fastocr.util import DesktopInfo, open_in_default
+from fastocr.util import DesktopInfo, open_in_default, get_environment_values
 
 if DesktopInfo.dbus_supported():
     from fastocr.bus import AppDBusObject
@@ -40,6 +40,34 @@ class SettingBackend(QObject):
     def open_setting_file(self):
         asyncio.gather(open_in_default(APP_SETTING_FILE.as_posix()))
 
+    # Consts
+    @pyqtProperty(str, constant=True)
+    def appver(self) -> str:
+        import pkg_resources
+        return pkg_resources.get_distribution('fastocr').version
+
+    @appver.setter
+    def appver(self, text: str):
+        pass
+
+    @pyqtProperty(list, constant=True)
+    def all_language_tags(self) -> list:
+        return ['JAP', 'KOR', 'FRE', 'SPA', 'GER', 'RUS']
+
+    @pyqtProperty(list, constant=True)
+    def all_language_names(self) -> list:
+        return ['Japanese', 'Korea', 'French', 'Spanish', 'Germany', 'Russian']
+
+    # Environment
+    @pyqtProperty(list, constant=True)
+    def about_data(self) -> list:
+        result = []
+        values = get_environment_values()
+        for k, v in values.items():
+            result.append({'name': k, 'value': str(v)})
+        return result
+
+    # Settings
     @pyqtProperty(str, constant=True)
     def appid(self) -> str:
         return self.setting.baidu_appid
@@ -158,6 +186,7 @@ class AppTray(QSystemTrayIcon):
         self.engine = QQmlApplicationEngine()
         self.setting = Setting()
         self.backend = SettingBackend(tray=self)
+        self.engine.setOutputWarningsToStandardError(False)
         self.engine.rootContext().setContextProperty('backend', self.backend)
         self.engine.load((Path(__file__).parent / 'qml' / 'main.qml').as_posix())
         self.setting_window = self.engine.rootObjects()[0]
